@@ -1,7 +1,7 @@
 # -*- mode: Perl -*-
 package MRTG_lib;
 ###################################################################
-# MRTG 2.17.0  Support library MRTG_lib.pm
+# MRTG 2.17.1  Support library MRTG_lib.pm
 ###################################################################
 # Created by Tobias Oetiker <tobi@oetiker.ch>
 #            and Dave Rand <dlr@bungi.com>
@@ -18,12 +18,6 @@ require 5.005;
 use strict;
 use vars qw($OS $SL $PS @EXPORT @ISA $VERSION %timestrpospattern);
 
-if (eval {local $SIG{__DIE__}; require Net_SNMP_util} ) {
-	import Net_SNMP_util;
-} else {
-	require SNMP_util; 
-        import SNMP_util;
-}
 
 my %mrtgrules;
 
@@ -662,7 +656,12 @@ sub readcfg ($$$$;$$) {
             warn("WARNING: You are running RRDCached in TCP mode.  This means that it will use its own Base Directory instead of WorkDir for storing the RRD files.  Also, changes to MaxBytes and DS Type will not be actioned after the RRD file has been created.\n");
         }
 	}
-
+    if ($cfg->{enablesnmpv3} and $cfg->{enablesnmpv3} eq 'yes' and eval {local $SIG{__DIE__}; require Net_SNMP_util} ) {
+        import Net_SNMP_util;
+    } else {
+        require SNMP_util;
+        import SNMP_util;
+    }
 }
 
 # quick checks
@@ -685,7 +684,7 @@ sub quickcheck ($$$$$$) {
         }
     }
     die "ERROR: CFG Error Unknown Option \"$first\" in file $file on line $line or above.\n".
-      "           Check doc/reference.txt for Help\n\n";
+      "           Check doc/mrtg-reference.txt for Help\n\n";
 }
 
 # complex config checks
@@ -763,8 +762,10 @@ sub cfgcheck ($$$$;$) {
 	warn ("WARNING: If \"ThreshMailSender\" is defined, then \"ThreshMailServer\" must be defined too.\n");
         $error = "yes";
     }
- 
-    $cfg->{threshhyst} = 0.1 unless $cfg->{threshhyst};
+    # default ThreshHyst to 0.1 if ThreshDir is defined
+    if ($cfg->{threshdir}){
+        $cfg->{threshhyst} = 0.1 unless $cfg->{threshhyst};
+    }
     # build relativ path from htmldir to image dir.
     my @htmldir = split /\Q${MRTG_lib::SL}\E+/, $$cfg{htmldir};
     my @imagedir =  split /\Q${MRTG_lib::SL}\E+/, $$cfg{imagedir};
@@ -1109,6 +1110,12 @@ sub cfgcheck ($$$$;$) {
         if (! defined $$rcfg{'yscale'}{$rou}) {
             $$rcfg{'yscale'}{$rou} = 1.0;
         }
+        if (defined $$rcfg{'options'}{'pngdate'}{$rou}) {
+            $$rcfg{'timestrpos'}{$rou} = 'RU';
+            $$rcfg{'timestrfmt'}{$rou} = "%Y-%m-%d %H:%M %Z";
+
+            delete $$rcfg{'options'}{'pntdate'}{$rou}
+        }
         if (! defined $$rcfg{'timestrpos'}{$rou}) {
             $$rcfg{'timestrpos'}{$rou} = 'NO';
         }
@@ -1719,7 +1726,7 @@ sub populateconfcache ($$$$$) {
 	next if $confcache->{___deadhosts}{$hostkey} and time - $confcache->{___deadhosts}{$hostkey} < 300;
 	$SNMP_Session::errmsg = undef;
 	$Net_SNMP_util::ErrorMessage = undef;
-	@ret = snmpwalk(v4onlyifnecessary($host, $ipv4only), $snmpoptions, $node);
+	@ret = &main::snmpwalk(v4onlyifnecessary($host, $ipv4only), $snmpoptions, $node);
 	unless ( $SNMP_Session::errmsg or $Net_SNMP_util::ErrorMessage){
 	    foreach my $ret (@ret)
 	      {
@@ -1747,7 +1754,7 @@ sub populateconfcache ($$$$$) {
     }
     $SNMP_Session::errmsg = undef;
     $Net_SNMP_util::ErrorMessage = undef;
-    @ret = snmpwalk(v4onlyifnecessary($host, $ipv4only), $snmpoptions, "ifPhysAddress");
+    @ret = &main::snmpwalk(v4onlyifnecessary($host, $ipv4only), $snmpoptions, "ifPhysAddress");
     unless ( $SNMP_Session::errmsg or $Net_SNMP_util::ErrorMessage){
 	foreach my $ret (@ret)
 	  {
